this.zxcvbnts = this.zxcvbnts || {};
this.zxcvbnts["language-ar"] = (function (exports) {
    'use strict';

    // DEFLATE is a complex format; to read this code, you should probably check the RFC first:
    // https://tools.ietf.org/html/rfc1951
    // You may also wish to take a look at the guide I made about this program:
    // https://gist.github.com/101arrowz/253f31eb5abc3d9275ab943003ffecad
    // Some of the following code is similar to that of UZIP.js:
    // https://github.com/photopea/UZIP.js
    // However, the vast majority of the codebase has diverged from UZIP.js to increase performance and reduce bundle size.
    // Sometimes 0 will appear where -1 would be more appropriate. This is because using a uint
    // is better for memory in most engines (I *think*).

    // aliases for shorter compressed code (most minifers don't do this)
    var u8 = Uint8Array, u16 = Uint16Array, i32 = Int32Array;
    // fixed length extra bits
    var fleb = new u8([0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 1, 1, 2, 2, 2, 2, 3, 3, 3, 3, 4, 4, 4, 4, 5, 5, 5, 5, 0, /* unused */ 0, 0, /* impossible */ 0]);
    // fixed distance extra bits
    var fdeb = new u8([0, 0, 0, 0, 1, 1, 2, 2, 3, 3, 4, 4, 5, 5, 6, 6, 7, 7, 8, 8, 9, 9, 10, 10, 11, 11, 12, 12, 13, 13, /* unused */ 0, 0]);
    // code length index map
    var clim = new u8([16, 17, 18, 0, 8, 7, 9, 6, 10, 5, 11, 4, 12, 3, 13, 2, 14, 1, 15]);
    // get base, reverse index map from extra bits
    var freb = function (eb, start) {
        var b = new u16(31);
        for (var i = 0; i < 31; ++i) {
            b[i] = start += 1 << eb[i - 1];
        }
        // numbers here are at max 18 bits
        var r = new i32(b[30]);
        for (var i = 1; i < 30; ++i) {
            for (var j = b[i]; j < b[i + 1]; ++j) {
                r[j] = ((j - b[i]) << 5) | i;
            }
        }
        return { b: b, r: r };
    };
    var _a = freb(fleb, 2), fl = _a.b, revfl = _a.r;
    // we can ignore the fact that the other numbers are wrong; they never happen anyway
    fl[28] = 258, revfl[258] = 28;
    var _b = freb(fdeb, 0), fd = _b.b;
    // map of value to reverse (assuming 16 bits)
    var rev = new u16(32768);
    for (var i = 0; i < 32768; ++i) {
        // reverse table algorithm from SO
        var x = ((i & 0xAAAA) >> 1) | ((i & 0x5555) << 1);
        x = ((x & 0xCCCC) >> 2) | ((x & 0x3333) << 2);
        x = ((x & 0xF0F0) >> 4) | ((x & 0x0F0F) << 4);
        rev[i] = (((x & 0xFF00) >> 8) | ((x & 0x00FF) << 8)) >> 1;
    }
    // create huffman tree from u8 "map": index -> code length for code index
    // mb (max bits) must be at most 15
    // TODO: optimize/split up?
    var hMap = (function (cd, mb, r) {
        var s = cd.length;
        // index
        var i = 0;
        // u16 "map": index -> # of codes with bit length = index
        var l = new u16(mb);
        // length of cd must be 288 (total # of codes)
        for (; i < s; ++i) {
            if (cd[i])
                ++l[cd[i] - 1];
        }
        // u16 "map": index -> minimum code for bit length = index
        var le = new u16(mb);
        for (i = 1; i < mb; ++i) {
            le[i] = (le[i - 1] + l[i - 1]) << 1;
        }
        var co;
        if (r) {
            // u16 "map": index -> number of actual bits, symbol for code
            co = new u16(1 << mb);
            // bits to remove for reverser
            var rvb = 15 - mb;
            for (i = 0; i < s; ++i) {
                // ignore 0 lengths
                if (cd[i]) {
                    // num encoding both symbol and bits read
                    var sv = (i << 4) | cd[i];
                    // free bits
                    var r_1 = mb - cd[i];
                    // start value
                    var v = le[cd[i] - 1]++ << r_1;
                    // m is end value
                    for (var m = v | ((1 << r_1) - 1); v <= m; ++v) {
                        // every 16 bit value starting with the code yields the same result
                        co[rev[v] >> rvb] = sv;
                    }
                }
            }
        }
        else {
            co = new u16(s);
            for (i = 0; i < s; ++i) {
                if (cd[i]) {
                    co[i] = rev[le[cd[i] - 1]++] >> (15 - cd[i]);
                }
            }
        }
        return co;
    });
    // fixed length tree
    var flt = new u8(288);
    for (var i = 0; i < 144; ++i)
        flt[i] = 8;
    for (var i = 144; i < 256; ++i)
        flt[i] = 9;
    for (var i = 256; i < 280; ++i)
        flt[i] = 7;
    for (var i = 280; i < 288; ++i)
        flt[i] = 8;
    // fixed distance tree
    var fdt = new u8(32);
    for (var i = 0; i < 32; ++i)
        fdt[i] = 5;
    // fixed length map
    var flrm = /*#__PURE__*/ hMap(flt, 9, 1);
    // fixed distance map
    var fdrm = /*#__PURE__*/ hMap(fdt, 5, 1);
    // find max of array
    var max = function (a) {
        var m = a[0];
        for (var i = 1; i < a.length; ++i) {
            if (a[i] > m)
                m = a[i];
        }
        return m;
    };
    // read d, starting at bit p and mask with m
    var bits = function (d, p, m) {
        var o = (p / 8) | 0;
        return ((d[o] | (d[o + 1] << 8)) >> (p & 7)) & m;
    };
    // read d, starting at bit p continuing for at least 16 bits
    var bits16 = function (d, p) {
        var o = (p / 8) | 0;
        return ((d[o] | (d[o + 1] << 8) | (d[o + 2] << 16)) >> (p & 7));
    };
    // get end of byte
    var shft = function (p) { return ((p + 7) / 8) | 0; };
    // typed array slice - allows garbage collector to free original reference,
    // while being more compatible than .slice
    var slc = function (v, s, e) {
        if (s == null || s < 0)
            s = 0;
        if (e == null || e > v.length)
            e = v.length;
        // can't use .constructor in case user-supplied
        return new u8(v.subarray(s, e));
    };
    // error codes
    var ec = [
        'unexpected EOF',
        'invalid block type',
        'invalid length/literal',
        'invalid distance',
        'stream finished',
        'no stream handler',
        ,
        'no callback',
        'invalid UTF-8 data',
        'extra field too long',
        'date not in range 1980-2099',
        'filename too long',
        'stream finishing',
        'invalid zip data'
        // determined by unknown compression method
    ];
    var err = function (ind, msg, nt) {
        var e = new Error(msg || ec[ind]);
        e.code = ind;
        if (Error.captureStackTrace)
            Error.captureStackTrace(e, err);
        if (!nt)
            throw e;
        return e;
    };
    // expands raw DEFLATE data
    var inflt = function (dat, st, buf, dict) {
        // source length       dict length
        var sl = dat.length, dl = 0;
        if (!sl || st.f && !st.l)
            return buf || new u8(0);
        var noBuf = !buf;
        // have to estimate size
        var resize = noBuf || st.i != 2;
        // no state
        var noSt = st.i;
        // Assumes roughly 33% compression ratio average
        if (noBuf)
            buf = new u8(sl * 3);
        // ensure buffer can fit at least l elements
        var cbuf = function (l) {
            var bl = buf.length;
            // need to increase size to fit
            if (l > bl) {
                // Double or set to necessary, whichever is greater
                var nbuf = new u8(Math.max(bl * 2, l));
                nbuf.set(buf);
                buf = nbuf;
            }
        };
        //  last chunk         bitpos           bytes
        var final = st.f || 0, pos = st.p || 0, bt = st.b || 0, lm = st.l, dm = st.d, lbt = st.m, dbt = st.n;
        // total bits
        var tbts = sl * 8;
        do {
            if (!lm) {
                // BFINAL - this is only 1 when last chunk is next
                final = bits(dat, pos, 1);
                // type: 0 = no compression, 1 = fixed huffman, 2 = dynamic huffman
                var type = bits(dat, pos + 1, 3);
                pos += 3;
                if (!type) {
                    // go to end of byte boundary
                    var s = shft(pos) + 4, l = dat[s - 4] | (dat[s - 3] << 8), t = s + l;
                    if (t > sl) {
                        if (noSt)
                            err(0);
                        break;
                    }
                    // ensure size
                    if (resize)
                        cbuf(bt + l);
                    // Copy over uncompressed data
                    buf.set(dat.subarray(s, t), bt);
                    // Get new bitpos, update byte count
                    st.b = bt += l, st.p = pos = t * 8, st.f = final;
                    continue;
                }
                else if (type == 1)
                    lm = flrm, dm = fdrm, lbt = 9, dbt = 5;
                else if (type == 2) {
                    //  literal                            lengths
                    var hLit = bits(dat, pos, 31) + 257, hcLen = bits(dat, pos + 10, 15) + 4;
                    var tl = hLit + bits(dat, pos + 5, 31) + 1;
                    pos += 14;
                    // length+distance tree
                    var ldt = new u8(tl);
                    // code length tree
                    var clt = new u8(19);
                    for (var i = 0; i < hcLen; ++i) {
                        // use index map to get real code
                        clt[clim[i]] = bits(dat, pos + i * 3, 7);
                    }
                    pos += hcLen * 3;
                    // code lengths bits
                    var clb = max(clt), clbmsk = (1 << clb) - 1;
                    // code lengths map
                    var clm = hMap(clt, clb, 1);
                    for (var i = 0; i < tl;) {
                        var r = clm[bits(dat, pos, clbmsk)];
                        // bits read
                        pos += r & 15;
                        // symbol
                        var s = r >> 4;
                        // code length to copy
                        if (s < 16) {
                            ldt[i++] = s;
                        }
                        else {
                            //  copy   count
                            var c = 0, n = 0;
                            if (s == 16)
                                n = 3 + bits(dat, pos, 3), pos += 2, c = ldt[i - 1];
                            else if (s == 17)
                                n = 3 + bits(dat, pos, 7), pos += 3;
                            else if (s == 18)
                                n = 11 + bits(dat, pos, 127), pos += 7;
                            while (n--)
                                ldt[i++] = c;
                        }
                    }
                    //    length tree                 distance tree
                    var lt = ldt.subarray(0, hLit), dt = ldt.subarray(hLit);
                    // max length bits
                    lbt = max(lt);
                    // max dist bits
                    dbt = max(dt);
                    lm = hMap(lt, lbt, 1);
                    dm = hMap(dt, dbt, 1);
                }
                else
                    err(1);
                if (pos > tbts) {
                    if (noSt)
                        err(0);
                    break;
                }
            }
            // Make sure the buffer can hold this + the largest possible addition
            // Maximum chunk size (practically, theoretically infinite) is 2^17
            if (resize)
                cbuf(bt + 131072);
            var lms = (1 << lbt) - 1, dms = (1 << dbt) - 1;
            var lpos = pos;
            for (;; lpos = pos) {
                // bits read, code
                var c = lm[bits16(dat, pos) & lms], sym = c >> 4;
                pos += c & 15;
                if (pos > tbts) {
                    if (noSt)
                        err(0);
                    break;
                }
                if (!c)
                    err(2);
                if (sym < 256)
                    buf[bt++] = sym;
                else if (sym == 256) {
                    lpos = pos, lm = null;
                    break;
                }
                else {
                    var add = sym - 254;
                    // no extra bits needed if less
                    if (sym > 264) {
                        // index
                        var i = sym - 257, b = fleb[i];
                        add = bits(dat, pos, (1 << b) - 1) + fl[i];
                        pos += b;
                    }
                    // dist
                    var d = dm[bits16(dat, pos) & dms], dsym = d >> 4;
                    if (!d)
                        err(3);
                    pos += d & 15;
                    var dt = fd[dsym];
                    if (dsym > 3) {
                        var b = fdeb[dsym];
                        dt += bits16(dat, pos) & (1 << b) - 1, pos += b;
                    }
                    if (pos > tbts) {
                        if (noSt)
                            err(0);
                        break;
                    }
                    if (resize)
                        cbuf(bt + 131072);
                    var end = bt + add;
                    if (bt < dt) {
                        var shift = dl - dt, dend = Math.min(dt, end);
                        if (shift + bt < 0)
                            err(3);
                        for (; bt < dend; ++bt)
                            buf[bt] = dict[shift + bt];
                    }
                    for (; bt < end; ++bt)
                        buf[bt] = buf[bt - dt];
                }
            }
            st.l = lm, st.p = lpos, st.b = bt, st.f = final;
            if (lm)
                final = 1, st.m = lbt, st.d = dm, st.n = dbt;
        } while (!final);
        // don't reallocate for streams or user buffers
        return bt != buf.length && noBuf ? slc(buf, 0, bt) : buf.subarray(0, bt);
    };
    // empty
    var et = /*#__PURE__*/ new u8(0);
    // gzip footer: -8 to -4 = CRC, -4 to -0 is length
    // gzip start
    var gzs = function (d) {
        if (d[0] != 31 || d[1] != 139 || d[2] != 8)
            err(6, 'invalid gzip data');
        var flg = d[3];
        var st = 10;
        if (flg & 4)
            st += (d[10] | d[11] << 8) + 2;
        for (var zs = (flg >> 3 & 1) + (flg >> 4 & 1); zs > 0; zs -= !d[st++])
            ;
        return st + (flg & 2);
    };
    // gzip length
    var gzl = function (d) {
        var l = d.length;
        return (d[l - 4] | d[l - 3] << 8 | d[l - 2] << 16 | d[l - 1] << 24) >>> 0;
    };
    // zlib start
    var zls = function (d, dict) {
        if ((d[0] & 15) != 8 || (d[0] >> 4) > 7 || ((d[0] << 8 | d[1]) % 31))
            err(6, 'invalid zlib data');
        if ((d[1] >> 5 & 1) == +!dict)
            err(6, 'invalid zlib data: ' + (d[1] & 32 ? 'need' : 'unexpected') + ' dictionary');
        return (d[1] >> 3 & 4) + 2;
    };
    /**
     * Expands DEFLATE data with no wrapper
     * @param data The data to decompress
     * @param opts The decompression options
     * @returns The decompressed version of the data
     */
    function inflateSync(data, opts) {
        return inflt(data, { i: 2 }, opts , opts );
    }
    /**
     * Expands GZIP data
     * @param data The data to decompress
     * @param opts The decompression options
     * @returns The decompressed version of the data
     */
    function gunzipSync(data, opts) {
        var st = gzs(data);
        if (st + 8 > data.length)
            err(6, 'invalid gzip data');
        return inflt(data.subarray(st, -8), { i: 2 }, new u8(gzl(data)), opts );
    }
    /**
     * Expands Zlib data
     * @param data The data to decompress
     * @param opts The decompression options
     * @returns The decompressed version of the data
     */
    function unzlibSync(data, opts) {
        return inflt(data.subarray(zls(data, opts ), -4), { i: 2 }, opts , opts );
    }
    /**
     * Expands compressed GZIP, Zlib, or raw DEFLATE data, automatically detecting the format
     * @param data The data to decompress
     * @param opts The decompression options
     * @returns The decompressed version of the data
     */
    function decompressSync(data, opts) {
        return (data[0] == 31 && data[1] == 139 && data[2] == 8)
            ? gunzipSync(data, opts)
            : ((data[0] & 15) != 8 || (data[0] >> 4) > 7 || ((data[0] << 8 | data[1]) % 31))
                ? inflateSync(data, opts)
                : unzlibSync(data, opts);
    }
    // text decoder
    var td = typeof TextDecoder != 'undefined' && /*#__PURE__*/ new TextDecoder();
    // text decoder stream
    var tds = 0;
    try {
        td.decode(et, { stream: true });
        tds = 1;
    }
    catch (e) { }
    // decode UTF8
    var dutf8 = function (d) {
        for (var r = '', i = 0;;) {
            var c = d[i++];
            var eb = (c > 127) + (c > 223) + (c > 239);
            if (i + eb > d.length)
                return { s: r, r: slc(d, i - 1) };
            if (!eb)
                r += String.fromCharCode(c);
            else if (eb == 3) {
                c = ((c & 15) << 18 | (d[i++] & 63) << 12 | (d[i++] & 63) << 6 | (d[i++] & 63)) - 65536,
                    r += String.fromCharCode(55296 | (c >> 10), 56320 | (c & 1023));
            }
            else if (eb & 1)
                r += String.fromCharCode((c & 31) << 6 | (d[i++] & 63));
            else
                r += String.fromCharCode((c & 15) << 12 | (d[i++] & 63) << 6 | (d[i++] & 63));
        }
    };
    /**
     * Converts a Uint8Array to a string
     * @param dat The data to decode to string
     * @param latin1 Whether or not to interpret the data as Latin-1. This should
     *               not need to be true unless encoding to binary string.
     * @returns The original UTF-8/Latin-1 string
     */
    function strFromU8(dat, latin1) {
        var r; if (td) {
            return td.decode(dat);
        }
        else {
            var _a = dutf8(dat), s = _a.s, r = _a.r;
            if (r.length)
                err(8);
            return s;
        }
    }

    const ascii85 = charsetToMap(`!"#$%&'()*+,-./0123456789:;<=>?@ABCDEFGHIJKLMNOPQRSTUVWXYZ[\\]^_\`abcdefghijklmnopqrstu`);
    const z85 = charsetToMap(`0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ.-:+=^!/*?&<>()[]{}@%$#`);
    const pow2 = 7225; // 85 ** 2
    const pow3 = 614125; // 85 ** 3
    const pow4 = 52200625; // 85 ** 4
    /** @param {"ascii85" | "z85" | string} [charset="z85"]
     *  @return {Uint8Array}  */
    function getMap(charset = "z85") {
        if (charset === "ascii85") {
            return ascii85;
        }
        if (charset.length === 85) {
            return charsetToMap(charset);
        }
        return z85;
    }
    /** @param {string} charset - 85 characters ASCII string */
    function charsetToMap(charset) {
        const ui8a = new Uint8Array(85);
        for (let i = 0; i < 85; i++) {
            ui8a[i] = charset.charAt(i).charCodeAt(0);
        }
        return ui8a;
    }
    /** @param {Uint8Array} mapOrig
     *  @return {Uint8Array}  */
    function getReverseMap(mapOrig) {
        const revMap = new Uint8Array(128);
        for (const [num, charCode] of Object.entries(mapOrig)) {
            revMap[charCode] = parseInt(num);
        }
        return revMap;
    }
    /**
     * Decodes Base85 string.
     * @param {string} base85 - base85 encoded string
     * @param {"ascii85" | "z85" | string} [charset="z85"] - 85 unique characters string
     * @return {Uint8Array}
     * */
    function decode(base85, charset) {
        const map = getMap(charset);
        const revMap = getReverseMap(map);
        const base85ab = new TextEncoder().encode(base85);
        const pad = (5 - (base85ab.length % 5)) % 5;
        const ints = new Uint8Array((Math.ceil(base85ab.length / 5) * 4) - pad);
        let dw = new DataView(ints.buffer);
        let i = 0;
        for (; i < base85ab.length / 5 - 1; i++) {
            const c1 = revMap[base85ab[i * 5 + 4]];
            const c2 = revMap[base85ab[i * 5 + 3]] * 85;
            const c3 = revMap[base85ab[i * 5 + 2]] * pow2;
            const c4 = revMap[base85ab[i * 5 + 1]] * pow3;
            const c5 = revMap[base85ab[i * 5]] * pow4;
            dw.setUint32(i * 4, c1 + c2 + c3 + c4 + c5);
        }
        const lCh = map[map.length - 1];
        const lastPart = new Uint8Array([...base85ab.slice(i * 5), lCh, lCh, lCh, lCh]);
        dw = new DataView(lastPart.buffer);
        const c1 = revMap[lastPart[4]];
        const c2 = revMap[lastPart[3]] * 85;
        const c3 = revMap[lastPart[2]] * pow2;
        const c4 = revMap[lastPart[1]] * pow3;
        const c5 = revMap[lastPart[0]] * pow4;
        dw.setUint32(0, c1 + c2 + c3 + c4 + c5);
        for (let j = 0; j < 4 - pad; j++) {
            ints[i * 4 + j] = lastPart[j];
        }
        return ints;
    }
    /** Alias to `decode`. */
    const decodeBase85 = decode;

    const encoded$2 = "abZy8n:ud:0S#e.tHG)W4UYX!h%-&Hlo?Y[e<WUd^Eg.0}U?qlGK.>>2?&W!VTH6ZTrd1R}jxk[@I!#Q>*%ho6%y*Zexp*zALIg*{t9Qw{.N+nez)Nq@-IL!Yht/oj]q1?W.^KH36%PhwW32#!E)TwPll:C!xDUd/1Tiv)dn=8EF4kQuoYmX<8<Re>grNw{v(#2cTI>WSM}ZarcOk(v#Y6+S+lp&.]Bj#gcQWbgxc[SuE#WKEn%L4:NF&4&xmx>y7Y/(5)*T9ED>)py$AkerMfZ?M)/zQJ2bdXejLb<6^Ag[?%Az&iNIpmo{!qd@%:6eAl+0H5K[)516tpVIdbgK+2+>zw@Oxsc?GOTxtF%6}M=QynU=5}P?=O5VZdHmVj=6GbecLgs}vPTLbQ0hmn<l.q36cfV#$sc=uup$N77V1/GvGSPoQ6}J9>R^@hUIQcx/y)xmP1y{>K0jhY$+zfM!7&2eWeP&ZcVO5-W^7!-x<LaQzgpL!54ioR/uh)bXLzCmZ7/lTujyR-w9ya#*[@Jm@v36+S69[iwm^H{c:vlkd6/FeNv1tF?VehCmCGI(F^0YIsvMc2{hmwd<sr8:FCO>#P3uS[]DbK9*$JJ%k]JX>op0u+*khb{:z*WZcsNmfI-<]jjeyL[kC4QZrJxP3vaq2qr3fe!XUgEaoL]vs$DfeAHl?3ondLHtjx+pnV4wd*FC11XpJObbcZN>3[P?QnuBx3{C}.<6k>?lBfX:Qa=^*9*K-0UA6p?*Rvtw2-o}SpO>Me5}XGORAdmJ.I}((>5$uQ-hyfca/D@^V$8)!U&+7e>QK*K7U/*4VV3]of4w(.PZ0CHLS.t1n.%0uMb^[fa%C8*4QD3vT3EpVg}8AcYi}fDy>B98GC0:P}9-.9ClS&3Eq{%IW2+UUSg87a(qxMDT!>Enf=2&OaM&+s0z0$tMv3>JQ]!:?t!6b5ahIcVmCN.$dplR7bg[xRnf{5U/c.CcdSGf${+!Z-s6+Um[?-b]3Kb@D<}KZu4Wano)FXHd>2J.q0IF2K)OHo64zbJa}ROqUS:v*RT//wUTf9Gqr}/Lq{JgAVZ]h]:9<H[xnj<GBWlRzN<pn>bB)eUR*?IF:27<v^il{7X<{O1o[M9d5>gB5M=BwQ9CCch^YrpO}7{b7u1yt}E5b/XV:tRqxa4pa4E7[/[d.JKfY/(t)*tDZ7GF}YNern[KbN?+=8ovcm+Pxs^mGt^eYc=e}(C!u/*WY!VyO[fln^A4EUY-lKX-Ewgq*^U*5>bLn^UTYxjAu@VN8a?AYLU9Tf+TB]Lp2R]!3JX5I0H.nBdlwI=.9K)5pKj&^Q+?:b-n5NIaqb5=e*cx]Jev<E6({hn<=>z.9H8TUL+n@)DLmIphQU4Iiwl*a+1o8NAN(fD*&yGJ}-NgY/uj}p=kH4wj0!SHPG@H+?vI.=>HfiSPye5YcB{Jv>5%m:wi>Z=jeo}BLx*{+*/#NT3bm5RWhGY2SCNS(U(^I]6WZ!0&T-HFlR!r[e{utiA?Ej=FPu)IPDI/ebm!xA.?O5mS=[d^L0Hy(=HC$!<o@JlP2g0A&@Cvl8KiLfJxKmStJnpR2^Hbt7Q1)NQhZL@#Tnbv3}ib000";

              const decoded$2 = decodeBase85(encoded$2);
              const decompressedBuf$2 = decompressSync(decoded$2);
              const decompressed$2 = strFromU8(decompressedBuf$2);
              const decompressedArray$2 = decompressed$2.split(',');

    const encoded$1 = "abZy8n:ud:0S$rxs-RC63}8+AoeM:5HaLY*RAy+L+t7mRpM!0.2-6@ovEtKS9y^kxqoaKPi}<f&k^+9t-W?@awI}3j.jdueSsU%]&e$?06H9BxsNHLZS4*Ryj:ABTNNVVq&c8<xX<UR@(>c.76Eo8j4+euhf3a%fYdbXuOj}O+7}=rDe}bbJK=rfVxR&vFTxOJee71[FGk6n5xV7mLTFGmcQ6nWt:fe)?jU{YN9m/=0K3p7Hkf!1?PV}[Dzo-x}W%T)->PTpy<kdyGW+4rJ=jA05Px?A87(jYhAewF#.3#DrF=SH-UP.6cam6}H2oNy+}pMehW7qx&I-Elg}*!Q1llr^R=}4<?9Tf@pOlcd7Av0&tLS4p/^[E=bD4w=gnP7<2JEL$tyE{QiBtxAM7&#gpVXcaqB?v5i>0SGsgL+ojXX^N*LMy*+";

              const decoded$1 = decodeBase85(encoded$1);
              const decompressedBuf$1 = decompressSync(decoded$1);
              const decompressed$1 = strFromU8(decompressedBuf$1);
              const decompressedArray$1 = decompressed$1.split(',');

    const encoded = "abZy8n:ud:0S@J80000000000";

              const decoded = decodeBase85(encoded);
              const decompressedBuf = decompressSync(decoded);
              const decompressed = strFromU8(decompressedBuf);
              const decompressedArray = decompressed.split(',');

    var translations = {
      warnings: {
        straightRow: 'من السهل تخمين الصفوف المستقيمة من المفاتيح على لوحة المفاتيح.',
        keyPattern: 'من السهل تخمين أنماط لوحة المفاتيح القصيرة.',
        simpleRepeat: 'من السهل تخمين الأحرف المتكررة مثل "aaa".',
        extendedRepeat: 'من السهل تخمين أنماط الأحرف المتكررة مثل "abcabcabc".',
        sequences: 'من السهل تخمين تسلسلات الأحرف الشائعة مثل "abc".',
        recentYears: 'من السهل تخمين السنوات الأخيرة.',
        dates: 'من السهل تخمين التواريخ.',
        topTen: 'هذه كلمة مرور مستخدمة بكثرة.',
        topHundred: 'هذه كلمة مرور مستخدمة بشكل متكرر.',
        common: 'هذه كلمة مرور شائعة الاستخدام.',
        similarToCommon: 'هذه كلمة مرور مشابهة لكلمة مرور شائعة الاستخدام.',
        wordByItself: 'من السهل تخمين الكلمات المنفردة.',
        namesByThemselves: 'من السهل تخمين الأسماء المنفردة أو الألقاب.',
        commonNames: 'من السهل تخمين الأسماء والألقاب الشائعة.',
        userInputs: 'يجب ألا يكون هناك أي بيانات شخصية أو متعلقة بالصفحة.',
        pwned: 'تم الكشف عن كلمة المرور الخاصة بك عن طريق تسريب بيانات على الإنترنت.'
      },
      suggestions: {
        l33t: "تجنب الاستبدالات المتوقعة للأحرف مثل '@' بدل 'a'.",
        reverseWords: 'تجنب التهجئة المعكوسة للكلمات الشائعة.',
        allUppercase: 'قم بتكبير بعض الحروف ولكن ليس جميعها.',
        capitalization: 'قم بتكبير حروف أخرى وليس الحرف الأول فقط',
        dates: 'تجنب التواريخ والسنوات المرتبطة بك.',
        recentYears: 'تجنب السنوات الأخيرة.',
        associatedYears: 'تجنب السنوات المرتبطة بك.',
        sequences: 'تجنب تسلسل الأحرف الشائعة.',
        repeated: 'تجنب الكلمات والأحرف المتكررة.',
        longerKeyboardPattern: 'استخدم أنماط لوحة المفاتيح أطول وقم بتغيير اتجاه الكتابة عدة مرات.',
        anotherWord: 'أضف المزيد من الكلمات الأقل شيوعًا.',
        useWords: 'استخدم كلمات متعددة، ولكن تجنب العبارات الشائعة.',
        noNeed: 'يمكنك إنشاء كلمات مرور قوية دون استخدام الرموز أو الأرقام أو الأحرف الكبيرة.',
        pwned: 'إذا كنت تستخدم كلمة المرور هذه في مكان آخر، فيجب عليك تغييرها.'
      },
      timeEstimation: {
        ltSecond: 'أقل من ثانية',
        second: '{base} ثانية',
        seconds: '{base} ثوانٍ',
        minute: '{base} دقيقة',
        minutes: '{base} دقائق',
        hour: '{base} ساعة',
        hours: '{base} ساعات',
        day: '{base} يوم',
        days: '{base} أيام',
        month: '{base} شهر',
        months: '{base} شهور',
        year: '{base} سنة',
        years: '{base} سنين',
        centuries: 'قرون'
      }
    };

    // This file is auto generated by data-scripts/_helpers/runtime.ts
    const dictionary = {
      'firstnames-ar': decompressedArray$2,
      'lastnames-ar': decompressedArray$1,
      'wikipedia-ar': decompressedArray
    };

    exports.dictionary = dictionary;
    exports.translations = translations;

    return exports;

})({});
//# sourceMappingURL=zxcvbn-ts.js.map
